@@ -268,7 +268,7 @@ gistandard(cpl_parameterlist* config, cpl_frameset* set)
 
     GiInstrumentMode mode;
 
-    GiRecipeInfo info = {(cxchar*)_id, 1, NULL};
+    GiRecipeInfo info = {(cxchar*)_id, 1, NULL, config};
 
     GiGroupInfo groups[] = {
         {GIFRAME_STANDARD, CPL_FRAME_GROUP_RAW},
@@ -527,14 +527,15 @@ gistandard(cpl_parameterlist* config, cpl_frameset* set)
                                      "Total exposure time of all frames "
                                      "combined");
 
-        cpl_propertylist_append_int(properties, GIALIAS_DATANCOM, nstandard);
-        cpl_propertylist_set_comment(properties, GIALIAS_DATANCOM, "Number of "
-                              "frames combined");
 
         cpl_propertylist_erase(properties, GIALIAS_TPLEXPNO);
 
     }
 
+    cpl_propertylist_append_int(properties, GIALIAS_DATANCOM, nstandard);
+    cpl_propertylist_set_comment(properties, GIALIAS_DATANCOM, "Number of "
+                          "combined frames");
+
 
     /*
      * Prepare for bias subtraction
